# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGP, AsyncSGP
from tests.utils import assert_matches_type
from scale_gp.types import CreateAccountResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAccounts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: SGP) -> None:
        account = client.accounts.create(
            account_name="string",
        )
        assert_matches_type(CreateAccountResponse, account, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: SGP) -> None:
        response = client.accounts.with_raw_response.create(
            account_name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        account = response.parse()
        assert_matches_type(CreateAccountResponse, account, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: SGP) -> None:
        with client.accounts.with_streaming_response.create(
            account_name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            account = response.parse()
            assert_matches_type(CreateAccountResponse, account, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAccounts:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncSGP) -> None:
        account = await async_client.accounts.create(
            account_name="string",
        )
        assert_matches_type(CreateAccountResponse, account, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncSGP) -> None:
        response = await async_client.accounts.with_raw_response.create(
            account_name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        account = await response.parse()
        assert_matches_type(CreateAccountResponse, account, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncSGP) -> None:
        async with async_client.accounts.with_streaming_response.create(
            account_name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            account = await response.parse()
            assert_matches_type(CreateAccountResponse, account, path=["response"])

        assert cast(Any, response.is_closed) is True
