# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGP, AsyncSGP
from tests.utils import assert_matches_type
from scale_gp.types import (
    EvaluationDatasetResponse,
    PaginationResponseEvaluationDataset,
    PublishEvaluationDatasetDraftResponse,
    AutoGeneratedDraftTestCaseApproveBatchResponse,
)
from scale_gp.types.shared import DeleteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvaluationDatasets:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create_overload_1(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_1(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
            type="manual",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_create_overload_1(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_1(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_create_overload_2(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_create_with_all_params_overload_2(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
            type="autogenerated",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_create_overload_2(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_create_overload_2(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.retrieve(
            "string",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.retrieve(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.retrieve(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_update_overload_1(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            "string",
            name="string",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_update_with_all_params_overload_1(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            "string",
            name="string",
            restore=True,
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_update_overload_1(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.update(
            "string",
            name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_1(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.update(
            "string",
            name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_1(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.update(
                "",
                name="string",
            )

    @parametrize
    def test_method_update_overload_2(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.update(
            "string",
            restore=True,
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_update_overload_2(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.update(
            "string",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_update_overload_2(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.update(
            "string",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update_overload_2(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.update(
                "",
                restore=True,
            )

    @parametrize
    def test_method_list(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.list()
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.list(
            account_id="string",
            include_archived=True,
            limit=1,
            page=1,
        )
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.delete(
            "string",
        )
        assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.delete(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.delete(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_approve_batch(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_approve_batch_with_all_params(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
            force=True,
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_approve_batch(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_approve_batch(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_approve_batch(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.approve_batch(
                "",
                autogenerated_draft_test_cases=["string", "string", "string"],
            )

    @parametrize
    def test_method_publish(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.publish(
            "string",
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_method_publish_with_all_params(self, client: SGP) -> None:
        evaluation_dataset = client.evaluation_datasets.publish(
            "string",
            force=True,
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_raw_response_publish(self, client: SGP) -> None:
        response = client.evaluation_datasets.with_raw_response.publish(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    def test_streaming_response_publish(self, client: SGP) -> None:
        with client.evaluation_datasets.with_streaming_response.publish(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_publish(self, client: SGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.with_raw_response.publish(
                "",
            )


class TestAsyncEvaluationDatasets:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create_overload_1(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_1(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
            type="manual",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_1(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_1(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.create(
            account_id="string",
            name="string",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_create_overload_2(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_create_with_all_params_overload_2(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
            type="autogenerated",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_create_overload_2(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_create_overload_2(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.create(
            account_id="string",
            knowledge_base_id="string",
            name="string",
            schema_type="GENERATION",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.retrieve(
            "string",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.retrieve(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.retrieve(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_update_overload_1(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            "string",
            name="string",
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_update_with_all_params_overload_1(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            "string",
            name="string",
            restore=True,
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_1(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.update(
            "string",
            name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_1(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.update(
            "string",
            name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_1(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.update(
                "",
                name="string",
            )

    @parametrize
    async def test_method_update_overload_2(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.update(
            "string",
            restore=True,
        )
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_update_overload_2(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.update(
            "string",
            restore=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_update_overload_2(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.update(
            "string",
            restore=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update_overload_2(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.update(
                "",
                restore=True,
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.list()
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.list(
            account_id="string",
            include_archived=True,
            limit=1,
            page=1,
        )
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(PaginationResponseEvaluationDataset, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.delete(
            "string",
        )
        assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.delete(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.delete(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(DeleteResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_approve_batch(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_approve_batch_with_all_params(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
            force=True,
        )
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_approve_batch(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_approve_batch(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.approve_batch(
            "string",
            autogenerated_draft_test_cases=["string", "string", "string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(AutoGeneratedDraftTestCaseApproveBatchResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_approve_batch(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.approve_batch(
                "",
                autogenerated_draft_test_cases=["string", "string", "string"],
            )

    @parametrize
    async def test_method_publish(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.publish(
            "string",
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_method_publish_with_all_params(self, async_client: AsyncSGP) -> None:
        evaluation_dataset = await async_client.evaluation_datasets.publish(
            "string",
            force=True,
        )
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_raw_response_publish(self, async_client: AsyncSGP) -> None:
        response = await async_client.evaluation_datasets.with_raw_response.publish(
            "string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

    @parametrize
    async def test_streaming_response_publish(self, async_client: AsyncSGP) -> None:
        async with async_client.evaluation_datasets.with_streaming_response.publish(
            "string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(PublishEvaluationDatasetDraftResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_publish(self, async_client: AsyncSGP) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.with_raw_response.publish(
                "",
            )
